@@ -54,7 +54,7 @@ statsNA <- function(x, bins = 4, printOnly = TRUE) {
   ## Input check
   ## 
   
-  if(!is.null(dim(data)))
+  if(!is.null(dim(data)) && dim(data)[2] != 1)
   {stop("Input x is not univariate")}
   
   if(!is.numeric(data))
